1.0.0 API documentation: GLM_GTX_projection

| 1.0.0 API documentation

Functions
GLM_GTX_projection
Experimental extensions

## Functions
template<typename genType >
GLM_FUNC_DECL genType | proj (genType const &x, genType const &Normal)
| Projects x on Normal. More...

## Detailed Description

Include <glm/gtx/projection.hpp> to use the features of this extension.

Projection of a vector to other one

## Function Documentation

## ◆ proj()

GLM_FUNC_DECL genType glm::proj | ( | genType const & | x,
|  | genType const & | Normal
| ) |  |

Projects x on Normal.

Parameters

  [in] | x | A vector to project
  [in] | Normal | A normal that doesn't need to be of unit length.

See also
  GLM_GTX_projection